@@ -107,11 +107,11 @@ import Data.Proxy
 
 -- Type-safe cache creation
 tokenCache <- do
-  store <- createInMemoryStore @'TokenBucket
+  store <- createInMemoryStore \@'TokenBucket
   return $ newCache TokenBucket store
 
 fixedWindowCache <- do
-  store <- createInMemoryStore @'FixedWindow  
+  store <- createInMemoryStore \@'FixedWindow  
   return $ newCache FixedWindow store
 @
 
@@ -130,7 +130,7 @@ newCount <- incrementCache fixedWindowCache "api_key" 60
 
 @
 -- Composite key generation
-let userKey = makeCacheKey TokenBucket "zone1" "user456"
+let userKey = makeCacheKey "throttle1" TokenBucket "zone1" "user456"
 writeCache tokenCache userKey state 7200
 
 -- Cleanup and reset
@@ -211,6 +211,9 @@ module Keter.RateLimiter.Cache
     -- * Entry Creation
   , createTokenBucketEntry
   , createLeakyBucketEntry
+    -- * Algorithm utilities
+  , algoToText
+  , parseAlgoText
   ) where
 
 import Control.Concurrent.STM
@@ -219,8 +222,10 @@ import Control.Monad.IO.Class (MonadIO, liftIO)
 import Control.Monad (void, forever)
 import Control.Concurrent (forkIO, threadDelay)
 import Data.Aeson (ToJSON, FromJSON, decodeStrict, encode)
+import Data.Aeson.Types (Parser)
 import qualified Data.ByteString.Lazy as LBS
 import Data.Text (Text)
+import qualified Data.Text as Tx (unpack, toLower)
 import qualified Data.TinyLRU as TinyLRU
 import Data.Text.Encoding (encodeUtf8, decodeUtf8')
 import qualified Data.Cache as C
@@ -305,18 +310,18 @@ algorithmPrefix TinyLRU       = "tiny_lru"
 --
 -- ==== Type Parameters
 --
--- * @store@: The storage backend type (e.g., 'InMemoryStore', Redis, etc.)
--- * The algorithm is captured in the store type for type safety
+-- The 'store' parameter represents the storage backend type (e.g., 'InMemoryStore', Redis, etc.)
+-- The algorithm is captured in the store type for type safety
 --
 -- ==== Example Usage
 --
 -- @
 -- -- Create a token bucket cache
--- tokenStore <- createInMemoryStore @'TokenBucket
+-- tokenStore <- createInMemoryStore \@'TokenBucket
 -- let tokenCache = Cache TokenBucket tokenStore
 --
 -- -- Create a fixed window cache
--- counterStore <- createInMemoryStore @'FixedWindow
+-- counterStore <- createInMemoryStore \@'FixedWindow
 -- let counterCache = Cache FixedWindow counterStore
 -- @
 data Cache store = Cache
@@ -521,11 +526,11 @@ data InMemoryStore (a :: Algorithm) where
 --
 -- @
 -- -- Compiler ensures correct store type
--- tokenStore <- createStore @'TokenBucket    -- Creates TokenBucketStore
--- counterStore <- createStore @'FixedWindow  -- Creates CounterStore
+-- tokenStore <- createStore \@'TokenBucket    -- Creates TokenBucketStore
+-- counterStore <- createStore \@'FixedWindow  -- Creates CounterStore
 -- 
 -- -- This would be a compile error:
--- -- tokenStore <- createStore @'SlidingWindow  -- Type mismatch!
+-- -- tokenStore <- createStore \@'SlidingWindow  -- Type mismatch!
 -- @
 --
 -- ==== Automatic Services
@@ -637,12 +642,12 @@ waitUntilNextPurge startTime remainingMicros purgeSignal = do
 --
 -- @
 -- -- These are all valid and type-safe:
--- tokenStore <- createInMemoryStore @'TokenBucket
--- counterStore <- createInMemoryStore @'FixedWindow
--- lruStore <- createInMemoryStore @'TinyLRU
+-- tokenStore <- createInMemoryStore \@'TokenBucket
+-- counterStore <- createInMemoryStore \@'FixedWindow
+-- lruStore <- createInMemoryStore \@'TinyLRU
 --
 -- -- This would be a compile error (typo):
--- -- badStore <- createInMemoryStore @'TokenBuckett  -- Not a valid algorithm
+-- -- badStore <- createInMemoryStore \@'TokenBuckett  -- Not a valid algorithm
 -- @
 --
 -- ==== Background Services
@@ -660,8 +665,8 @@ waitUntilNextPurge startTime remainingMicros purgeSignal = do
 --
 -- main = do
 --   -- Create stores for different algorithms
---   tokenStore <- createInMemoryStore @'TokenBucket
---   slidingStore <- createInMemoryStore @'SlidingWindow
+--   tokenStore <- createInMemoryStore \@'TokenBucket
+--   slidingStore <- createInMemoryStore \@'SlidingWindow
 --   
 --   -- Use in cache creation
 --   let tokenCache = newCache TokenBucket tokenStore
@@ -687,7 +692,7 @@ createInMemoryStore = createStore @a
 --
 -- @
 -- -- Create a token bucket cache with in-memory storage
--- store <- createInMemoryStore @'TokenBucket
+-- store <- createInMemoryStore \@'TokenBucket
 -- let cache = newCache TokenBucket store
 --
 -- -- Later operations use the unified cache interface
@@ -1109,8 +1114,8 @@ focusInsertOrUpdate getState entry newVal = Focus.Focus
 --
 -- @
 -- -- Start worker for streaming rate limiter
--- startLeakyBucketWorker stateVar queue 100 2.0 "stream123"
--- -- Capacity: 100 requests, Leak rate: 2 requests/second
+-- startLeakyBucketWorker stateVar queue 100 2.0
+-- -- Capacity: 100 requests, Leak rate: 2 requests\/second
 -- @
 startLeakyBucketWorker
   :: TVar LeakyBucketState          -- ^ Shared bucket state
@@ -1198,7 +1203,7 @@ resetStoreWith tvar = do
   newCache <- C.newCache Nothing
   atomically $ writeTVar tvar newCache
 
--- | Compose a unique cache key from algorithm, IP zone, and user identifier.
+-- | Compose a unique cache key from throttle name, algorithm, IP zone, and user identifier.
 --
 -- Creates hierarchical cache keys that prevent collisions and enable
 -- efficient organization of rate limiting data. The key format follows
@@ -1207,17 +1212,7 @@ resetStoreWith tvar = do
 -- ==== Key Format
 --
 -- @
--- "algorithm_prefix:ip_zone:user_key"
--- @
---
--- ==== Examples
---
--- @
--- makeCacheKey TokenBucket "api" "user123"
--- -- Result: "token_bucket:api:user123"
---
--- makeCacheKey FixedWindow "web" "192.168.1.1"  
--- -- Result: "rate_limiter:web:192.168.1.1"
+-- \<algorithm>:\<throttleName>:\<ipZone>:\<userKey>
 -- @
 --
 -- ==== Use Cases
@@ -1233,8 +1228,124 @@ resetStoreWith tvar = do
 -- * __Query Efficiency__: Pattern-based queries and cleanup
 -- * __Debugging__: Clear key structure aids troubleshooting
 -- * __Monitoring__: Easy to aggregate metrics by zone or user type
-makeCacheKey :: Algorithm  -- ^ Rate limiting algorithm for prefix
-             -> Text       -- ^ IP zone or service identifier (e.g., "api", "web", "zone1")
-             -> Text       -- ^ User key (e.g., API key, user ID, IP address)
-             -> Text       -- ^ Complete hierarchical cache key
-makeCacheKey algo ipZone userKey = algorithmPrefix algo <> ":" <> ipZone <> ":" <> userKey
+--
+-- ==== Example
+--
+-- @
+-- -- Create key for API rate limiting
+-- let key = makeCacheKey "api_limit" TokenBucket "us-east-1" "user123"
+-- -- Result: "TokenBucket:api_limit:us-east-1:user123"
+--
+-- -- Create key for login attempts
+-- let key = makeCacheKey "login_attempts" FixedWindow "global" "192.168.1.1"
+-- -- Result: "FixedWindow:login_attempts:global:192.168.1.1"
+-- @
+makeCacheKey :: Text      -- ^ Throttle name (unique per rule)
+             -> Algorithm -- ^ Rate limiting algorithm
+             -> Text      -- ^ IP zone or region identifier
+             -> Text      -- ^ User key (user ID, IP address, API key, etc.)
+             -> Text      -- ^ Complete hierarchical cache key
+makeCacheKey throttleName algo ipZone userKey =
+  algoToText algo <> ":" <> throttleName <> ":" <> ipZone <> ":" <> userKey
+
+-- | Convert an Algorithm value to its canonical Text representation.
+--
+-- This function provides a standardized textual representation of rate limiting
+-- algorithms for serialization, logging, and configuration files. Each algorithm
+-- has exactly one canonical PascalCase representation matching the constructor names.
+--
+-- ==== Output Format
+--
+-- @
+-- FixedWindow    → "FixedWindow"
+-- SlidingWindow  → "SlidingWindow" 
+-- TokenBucket    → "TokenBucket"
+-- LeakyBucket    → "LeakyBucket"
+-- TinyLRU        → "TinyLRU"
+-- @
+--
+-- ==== Examples
+--
+-- @
+-- -- Basic usage
+-- algoToText TokenBucket  -- "TokenBucket"
+--
+-- -- Configuration serialization
+-- data RateLimitConfig = RateLimitConfig
+--   { algorithm :: Text, limit :: Int, window :: Int }
+-- 
+-- config = RateLimitConfig (algoToText SlidingWindow) 1000 3600
+--
+-- -- Logging
+-- logInfo $ "Using " <> algoToText currentAlgo <> " rate limiting"
+-- @
+--
+-- This function is pure, thread-safe, and forms a reversible pair with 'parseAlgoText'.
+-- Time complexity: O(1), Space complexity: O(1).
+algoToText :: Algorithm -- ^ The algorithm to convert
+           -> Text      -- ^ Canonical text representation
+algoToText FixedWindow   = "FixedWindow"
+algoToText SlidingWindow = "SlidingWindow"
+algoToText TokenBucket   = "TokenBucket"
+algoToText LeakyBucket   = "LeakyBucket"
+algoToText TinyLRU       = "TinyLRU"
+
+-- | Parse a Text representation back into an Algorithm value.
+--
+-- Provides flexible parsing with case-insensitive matching and hyphenated format support.
+-- Returns an Aeson Parser for seamless JSON integration with rich error reporting.
+--
+-- ==== Supported Formats
+--
+-- @
+-- Algorithm      │ Accepted Inputs (case-insensitive)
+-- ──────────────┼───────────────────────────────────
+-- FixedWindow   │ "fixedwindow", "fixed-window"
+-- SlidingWindow │ "slidingwindow", "sliding-window"
+-- TokenBucket   │ "tokenbucket", "token-bucket"
+-- LeakyBucket   │ "leakybucket", "leaky-bucket"
+-- TinyLRU       │ "tinylru", "tiny-lru"
+-- @
+--
+-- ==== Examples
+--
+-- @
+-- -- JSON parsing
+-- instance FromJSON RateLimitConfig where
+--   parseJSON = withObject "RateLimitConfig" $ \\o ->
+--     RateLimitConfig <$> (o .: "algorithm" >>= parseAlgoText)
+--                     <*> o .: "limit"
+--
+-- -- Configuration file (accepts flexible formats)
+-- parseAlgoText "token-bucket"    -- Success TokenBucket
+-- parseAlgoText "SLIDING-WINDOW"  -- Success SlidingWindow
+-- parseAlgoText "invalid"         -- Error "Unknown algorithm: invalid"
+-- @
+--
+-- ==== Error Handling
+--
+-- Calls 'fail' with descriptive error messages for invalid inputs. In aeson's
+-- Parser context, this provides rich error reporting with parsing context.
+--
+-- ==== Round-trip Property
+--
+-- @
+-- forall algo. parseAlgoText (algoToText algo) == Success algo
+-- @
+--
+-- This function is pure, thread-safe, with O(1) time complexity after O(n) normalization.
+parseAlgoText :: Text            -- ^ Text representation to parse
+              -> Parser Algorithm -- ^ Parsed algorithm or error
+parseAlgoText t =
+  case Tx.toLower t of
+    "fixedwindow"    -> pure FixedWindow
+    "fixed-window"   -> pure FixedWindow
+    "slidingwindow"  -> pure SlidingWindow
+    "sliding-window" -> pure SlidingWindow
+    "tokenbucket"    -> pure TokenBucket
+    "token-bucket"   -> pure TokenBucket
+    "leakybucket"    -> pure LeakyBucket
+    "leaky-bucket"   -> pure LeakyBucket
+    "tinylru"        -> pure TinyLRU
+    "tiny-lru"       -> pure TinyLRU
+    _ -> fail ("Unknown algorithm: " <> Tx.unpack t)
\ No newline at end of file
